.TH XARGS 1 "7 April 1995"
.SH NAME
xargs \- construct the arguments list(s) from stdin and execute a command
.SH SYNOPSIS
.B xargs
[
.B \-tp
] [
.BI \-ireplstr
]
.if t .ti +.5i
[
.I command
[ \|\fIinitial-args\fR ]
]
.SH DESCRIPTION
.B xargs
combines the fixed
.I initial-arguments
with arguments read from the standard input, to execute the specified
.I command
one or more times.
.LP
.IR command ,
which may be a shell file,
is searched for using one's
.BR \s-1$PATH\s+1 .
If
.I command
is omitted,
.B xargs
emulates the behaviour of
.BR /usr/bin/echo .
.LP
Arguments read in from the standard input are defined to be contiguous
strings of characters delimited by white space.
Empty lines are always discarded.
.LP
Each arguments-list is constructed starting with the
.IR initial-arguments ,
followed by the arguments read from the standard input
(Exception: see the
.B \-i
option).
When
.B \-i
option is not coded, the
.I initial-arguments
are followed by all arguments read continuously from the standard input
and then
.I command
is executed with the accumulated arguments.
.LP
.B xargs
will terminate if it receives a return code of
.BR \-1 ,
or if it cannot execute
.IR command .
When
.I command
is a shell script,
it should explicitly
.B exit
(see
.BR sh (1))
with an appropriate value to avoid accidentally returning with
.BR \-1 .
.SH OPTIONS
.TP
.B \-t
Trace mode.
The
.I command
and each constructed argument list are echoed to the standard error
just prior to their execution.
.TP
.B \-p
Prompt mode.
The user is asked whether to execute
.I command
each invocation.
Trace mode
.RB ( \-t )
is turned on to print the command instance to be executed,
followed by a
.B ?\|.\|.\|.
prompt.
A reply of
.B y
(optionally followed by anything) will execute the command;
anything else, including
just a
.SM return\s0,
skips that particular invocation of
.IR command .
.TP
.BI \-i replstr
Insert mode.
.I command
is executed for each argument from the standard input,
inserting it in
.I initial-arguments
for each occurrence of
.IR replstr .
.I initial-arguments
may contain one or more instances of
.IR replstr .
.B "{\|}"
is assumed for
.I replstr
if not specified. Note: If you run the
.BR csh (1)
or the
.BR tcsh (1)
you have to quote
.BR "{\|}" .
These shells use
.B "{"
and
.B "}"
for special filename substitution.
.SH EXAMLES
.LP
The following will move all files from directory
.B $1
to directory
.BR $2 ,
and echo each move command just before doing it:
.LP
.RS
.B "ls \|$1 \|| \|xargs \|\-i \|\-t \|mv \|$1/{\|} \|$2/{\|}"
.RE
.LP
The following will combine the output of
the parenthesized commands onto one line,
which is then echoed to the end of file
.BR log :
.LP
.RS
.B (logname; \|date; \|echo \|$0 \|$\(**) \|| \|xargs \|>>log
.RE
.LP
If
.B foo.tar
is untared in the wrong directory use the following to remove
only the files, created by
.BR tar .
.LP
.RS
.B "tar \|tf \|foo.tar \|| \|xargs \|rm \|\-rf"
.RE
.LP
.SH "SEE ALSO"
.BR csh (1),
.BR sh (1),
.BR tcsh (1),
.BR tar (1)
